==> prestashop_1.3.7.0.zip: prestashop/modules/treepodia/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{treepodia}prestashop>footer_93c433787599e3c6a61c27c9faad7cb1'] = 'Voir la vidéo';
$_MODULE['<{treepodia}prestashop>treepodia_17b4871fef9e13bfb529a4ffe1fe5119'] = 'Des vidéos de démonstration pour chacun de vos produits en 24h chrono!';
$_MODULE['<{treepodia}prestashop>treepodia_da1aeb3fb86487543eaa71ad0ccf62c3'] = 'Le module n\'est pas configuré.';
$_MODULE['<{treepodia}prestashop>treepodia_84d2e2420a102446904946c6611610e7'] = 'Choisissez une image ou télécharger ';
$_MODULE['<{treepodia}prestashop>treepodia_93f1004ef4f6180d1ff4c3e5e097535a'] = 'Nouveau logo :';
$_MODULE['<{treepodia}prestashop>treepodia_edf12239962e8a7a3caa250e04effbc6'] = 'Les vidéos augmentent les ventes, l\'engagement et la fidélité du client tout en augmentant l\'expérience utilisateur. ';
$_MODULE['<{treepodia}prestashop>treepodia_d59048f21fd887ad520398ce677be586'] = 'En savoir plus';
$_MODULE['<{treepodia}prestashop>treepodia_5f9c47215d373f15d8ab231a7803eafb'] = 'Mon compte Treepodia';
$_MODULE['<{treepodia}prestashop>treepodia_14d4af7e8b50a553a484be490748b8f8'] = 'Vous ne possédez pas de compte Treepodia Vidéo. Merci de vous enregistrer.';
$_MODULE['<{treepodia}prestashop>treepodia_0f98b7f230f3c91292f0de4c99e263f2'] = 'Enregistrement';
$_MODULE['<{treepodia}prestashop>treepodia_7f4f7010abf7fb495ffe34fad24dfc96'] = 'Code du compte vidéo';
$_MODULE['<{treepodia}prestashop>treepodia_b2b92abb20325484889c41eee1dd0f02'] = 'Le code du compte vidéo vous a été attribué automatiquement, il identifie de manière unique votre magasin.';
$_MODULE['<{treepodia}prestashop>treepodia_35ac6a06187c6dab85b3024e3f457dd9'] = 'Connectez vous sur votre compte pour changer vos préférences, configuration et suivre vos performances.';
$_MODULE['<{treepodia}prestashop>treepodia_b6d4223e60986fa4c9af77ee5f7149c5'] = 'Connexion';
$_MODULE['<{treepodia}prestashop>treepodia_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{treepodia}prestashop>treepodia_1e26f63fb925b49c1c741197cdc0dc7b'] = 'Implémentation par défaut';
$_MODULE['<{treepodia}prestashop>treepodia_a5267a427cf62a3a2bb94da92ecc9441'] = 'L\'implémentation par défaut, intègre le code de Treepodia dans votre magasin et affiche un lien vers la vidéo dans votre page produit.';
$_MODULE['<{treepodia}prestashop>treepodia_56850ed64712ade8b062ed706b0fdeb6'] = 'Logo actuel:';
$_MODULE['<{treepodia}prestashop>treepodia_fb38e79804eb66613570048c8499004a'] = 'Changer votre logo';
$_MODULE['<{treepodia}prestashop>treepodia_d236e43ab0c1cb8f7b8024b61903ded2'] = 'Logo affiché:';
$_MODULE['<{treepodia}prestashop>treepodia_5683dffd7845ddfa1eff733c6cd0e8a5'] = 'En dessous des liens utiles';
$_MODULE['<{treepodia}prestashop>treepodia_f87758e540d66df6593a86ab336b4ae2'] = 'En dessous de \"Plus d\'informations\"';
$_MODULE['<{treepodia}prestashop>treepodia_a9b7f57dac4f61416f6b514b0be84e53'] = 'Placer le logo ici:';
$_MODULE['<{treepodia}prestashop>treepodia_ac14a41802fbe8629670fca6b73a7a91'] = 'Image du produit';
$_MODULE['<{treepodia}prestashop>treepodia_945d5e233cf7d6240f6b783b36a374ff'] = 'Gauche';
$_MODULE['<{treepodia}prestashop>treepodia_4f1f6016fc9f3f2353c0cc7c67b292bd'] = 'Centre';
$_MODULE['<{treepodia}prestashop>treepodia_92b09c7c48c520c3c55e497875da437c'] = 'Droite';
$_MODULE['<{treepodia}prestashop>treepodia_1decb322633084a2d5c42c1ff047becd'] = 'Ou, implementer votre propre intégration';
$_MODULE['<{treepodia}prestashop>treepodia_d280700ce09ead998bbdf9b33d8c1cb4'] = 'Utilisez cette option si vous souhaitez utilisez votre code d\'intégration Treepodia. Le code d\'intégration sera désactivé si vous choisissez cette option.';
$_MODULE['<{treepodia}prestashop>treepodia_16280bdbf8c18890fb7637a26b97fe50'] = 'Cliquez ici pour savoir comment intégrer Treepodia avec votre propre code.';
$_MODULE['<{treepodia}prestashop>treepodia_d4dccb8ca2dac4e53c01bd9954755332'] = 'Sauvegarder';
$_MODULE['<{treepodia}prestashop>treepodia_3832f6deff5d50413adcbc9c06388c32'] = 'Fichier invalide';
$_MODULE['<{treepodia}prestashop>treepodia_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';

==> prestashop_1.4.0.2.zip: prestashop/modules/treepodia/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{treepodia}prestashop>treepodia_17b4871fef9e13bfb529a4ffe1fe5119'] = 'Des vidéos de démonstration pour chacun de vos produits en 24h chrono!';
$_MODULE['<{treepodia}prestashop>treepodia_da1aeb3fb86487543eaa71ad0ccf62c3'] = 'Le module n\'est pas configuré.';
$_MODULE['<{treepodia}prestashop>treepodia_84d2e2420a102446904946c6611610e7'] = 'Choisissez une image ou télécharger ';
$_MODULE['<{treepodia}prestashop>treepodia_93f1004ef4f6180d1ff4c3e5e097535a'] = 'Nouveau logo :';
$_MODULE['<{treepodia}prestashop>treepodia_edf12239962e8a7a3caa250e04effbc6'] = 'Les vidéos augmentent les ventes, l\'engagement et la fidélité du client tout en augmentant l\'expérience utilisateur. ';
$_MODULE['<{treepodia}prestashop>treepodia_d59048f21fd887ad520398ce677be586'] = 'En savoir plus';
$_MODULE['<{treepodia}prestashop>treepodia_5f9c47215d373f15d8ab231a7803eafb'] = 'Mon compte Treepodia';
$_MODULE['<{treepodia}prestashop>treepodia_14d4af7e8b50a553a484be490748b8f8'] = 'Vous ne possédez pas de compte Treepodia Vidéo. Merci de vous enregistrer.';
$_MODULE['<{treepodia}prestashop>treepodia_0f98b7f230f3c91292f0de4c99e263f2'] = 'Enregistrement';
$_MODULE['<{treepodia}prestashop>treepodia_7f4f7010abf7fb495ffe34fad24dfc96'] = 'Code du compte vidéo';
$_MODULE['<{treepodia}prestashop>treepodia_b2b92abb20325484889c41eee1dd0f02'] = 'Le code du compte vidéo vous a été attribué automatiquement, il identifie de manière unique votre magasin.';
$_MODULE['<{treepodia}prestashop>treepodia_35ac6a06187c6dab85b3024e3f457dd9'] = 'Connectez vous sur votre compte pour changer vos préférences, configuration et suivre vos performances.';
$_MODULE['<{treepodia}prestashop>treepodia_b6d4223e60986fa4c9af77ee5f7149c5'] = 'Connexion';
$_MODULE['<{treepodia}prestashop>treepodia_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{treepodia}prestashop>treepodia_1e26f63fb925b49c1c741197cdc0dc7b'] = 'Implémentation par défaut';
$_MODULE['<{treepodia}prestashop>treepodia_a5267a427cf62a3a2bb94da92ecc9441'] = 'L\'implémentation par défaut, intègre le code de Treepodia dans votre magasin et affiche un lien vers la vidéo dans votre page produit.';
$_MODULE['<{treepodia}prestashop>treepodia_56850ed64712ade8b062ed706b0fdeb6'] = 'Logo actuel:';
$_MODULE['<{treepodia}prestashop>treepodia_fb38e79804eb66613570048c8499004a'] = 'Changer votre logo';
$_MODULE['<{treepodia}prestashop>treepodia_a9b7f57dac4f61416f6b514b0be84e53'] = 'Placer le logo ici:';
$_MODULE['<{treepodia}prestashop>treepodia_ac14a41802fbe8629670fca6b73a7a91'] = 'Image du produit';
$_MODULE['<{treepodia}prestashop>treepodia_945d5e233cf7d6240f6b783b36a374ff'] = 'Gauche';
$_MODULE['<{treepodia}prestashop>treepodia_4f1f6016fc9f3f2353c0cc7c67b292bd'] = 'Centre';
$_MODULE['<{treepodia}prestashop>treepodia_92b09c7c48c520c3c55e497875da437c'] = 'Droite';
$_MODULE['<{treepodia}prestashop>treepodia_1decb322633084a2d5c42c1ff047becd'] = 'Ou, implementer votre propre intégration';
$_MODULE['<{treepodia}prestashop>treepodia_f7c01215c35a4154c975c2df0ffda0e5'] = 'Utiliser cette option si vous souhaitez implémenter le code de Treepodia vous même. L\'implémentation par défaut sera désactivée.';
$_MODULE['<{treepodia}prestashop>treepodia_16280bdbf8c18890fb7637a26b97fe50'] = 'Cliquez ici pour savoir comment intégrer Treepodia avec votre propre code.';
$_MODULE['<{treepodia}prestashop>treepodia_d4dccb8ca2dac4e53c01bd9954755332'] = 'Sauvegarder';
$_MODULE['<{treepodia}prestashop>treepodia_3832f6deff5d50413adcbc9c06388c32'] = 'Fichier invalide';
$_MODULE['<{treepodia}prestashop>treepodia_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
